Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1023)

Unified Diff: chrome/browser/views/first_run_view.h

Issue 2808006: Allow randomized search engines in selection dialog.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/views/first_run_view.h
===================================================================
--- chrome/browser/views/first_run_view.h (revision 49796)
+++ chrome/browser/views/first_run_view.h (working copy)
@@ -30,7 +30,8 @@
public:
explicit FirstRunView(Profile* profile, bool homepage_defined,
int import_items, int dont_import_items,
- bool search_engine_experiment);
+ bool search_engine_experiment,
+ bool randomize_search_engine_experiment);
virtual ~FirstRunView();
bool accepted() const { return accepted_;}
@@ -64,8 +65,9 @@
// Creates the dialog that allows the user to customize work items.
void OpenCustomizeDialog();
- // Creates the search engine selection dialog.
- void OpenSearchEngineDialog();
+ // Creates the search engine selection dialog. If |randomize|, the display
+ // of search engine logos should be randomized.
+ void OpenSearchEngineDialog(bool randomize);
views::Label* welcome_label_;
views::Label* actions_label_;

Powered by Google App Engine
This is Rietveld 408576698